Struct gdk_pixbuf::PixbufLoaderClass
source · [−]#[repr(C)]pub struct PixbufLoaderClass(_);Trait Implementations
sourceimpl Deref for PixbufLoaderClass
impl Deref for PixbufLoaderClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for PixbufLoaderClass
impl DerefMut for PixbufLoaderClass
sourceimpl IsClassFor for PixbufLoaderClass
impl IsClassFor for PixbufLoaderClass
type Instance = PixbufLoader
type Instance = PixbufLoader
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for PixbufLoaderClass
impl Sync for PixbufLoaderClass