[−][src]Struct gdk_pixbuf::TypedValue
A statically typed Value.
It dereferences to Value and can be used everywhere Value references are
accepted.
See the module documentation for more details.
Methods
impl<'a, T> TypedValue<T> where
T: FromValueOptional<'a> + SetValue, [src]
T: FromValueOptional<'a> + SetValue,
pub fn get(&'a self) -> Option<T>[src]
Returns the value.
Types that don't support a None value always return Some. See
get_some.
pub fn get_some(&'a self) -> T where
T: FromValue<'a>, [src]
T: FromValue<'a>,
Returns the value.
This method is only available for types that don't support a None
value.
pub fn set<U>(&mut self, value: Option<&U>) where
T: Borrow<U>,
U: SetValueOptional + ?Sized, [src]
T: Borrow<U>,
U: SetValueOptional + ?Sized,
Sets the value.
This method is only available for types that support a None value.
pub fn set_none(&mut self) where
T: SetValueOptional, [src]
T: SetValueOptional,
Sets the value to None.
This method is only available for types that support a None value.
pub fn set_some<U>(&mut self, value: &U) where
T: Borrow<U>,
U: SetValue + ?Sized, [src]
T: Borrow<U>,
U: SetValue + ?Sized,
Sets the value.
impl<'a, T> TypedValue<T> where
T: FromValueOptional<'a> + SetValue + Send, [src]
T: FromValueOptional<'a> + SetValue + Send,
pub fn into_send_value(self) -> SendValue[src]
Methods from Deref<Target = Value>
pub fn downcast_ref<'a, T>(&self) -> Option<&TypedValue<T>> where
T: FromValueOptional<'a> + SetValue, [src]
T: FromValueOptional<'a> + SetValue,
Tries to downcast to a &TypedValue.
Returns Some(&TypedValue<T>) if the value carries a type corresponding
to T and None otherwise.
pub fn get<'a, T>(&'a self) -> Option<T> where
T: FromValueOptional<'a>, [src]
T: FromValueOptional<'a>,
Tries to get a value of type T.
Returns Some if the type is correct and the value is not None.
This function doesn't distinguish between type mismatches and correctly
typed None values. Use downcast or is for that.
pub fn is<'a, T>(&self) -> bool where
T: FromValueOptional<'a> + SetValue, [src]
T: FromValueOptional<'a> + SetValue,
Returns true if the type of the value corresponds to T
or is a sub-type of T.
pub fn type_(&self) -> Type[src]
Returns the type of the value.